@@ -4,7 +4,7 @@
 #
 
 package Crypt::EAMessage;
-$Crypt::EAMessage::VERSION = '1.005';
+$Crypt::EAMessage::VERSION = '1.007';
 use v5.22;
 
 # ABSTRACT: Simple-to-use Abstraction of Encrypted Authenticated Messages
@@ -129,6 +129,16 @@ sub _encrypt_auth_internal ( $self, $input ) {
 }
 
 
+sub encrypt_auth_urlsafe ( $self, $input ) {
+    my $ct = $self->_encrypt_auth_internal($input);
+
+    my $urltext = encode_base64( $ct, "" );
+    $urltext =~ tr|\+/|-_|;
+
+    return "3$urltext";    # Type 3 = Modified Base 64
+}
+
+
 sub decrypt_auth ( $self, $ct ) {
     if ( length($ct) < 34 ) { die("Message too short to be valid") }
 
@@ -141,6 +151,11 @@ sub decrypt_auth ( $self, $ct ) {
         my $ascii = decode_base64($enc);    # It's okay if this ignores bad base64,
                                             # since we'll fail decryption.
         return $self->_decrypt_auth_internal($ascii);
+    } elsif ( $type eq '3' ) {
+        $enc =~ tr|-_|+/|;
+        my $ascii = decode_base64($enc);    # It's okay if this ignores bad base64,
+                                            # since we'll fail decryption.
+        return $self->_decrypt_auth_internal($ascii);
     } else {
         die("Unsupported encoding type");
     }
@@ -176,7 +191,7 @@ Crypt::EAMessage - Simple-to-use Abstraction of Encrypted Authenticated Messages
 
 =head1 VERSION
 
-version 1.005
+version 1.007
 
 =head1 SYNOPSIS
 
@@ -264,6 +279,20 @@ Note that when using line endings other than a blank ending (no line ending)
 or a standard newline, you should strip the new line identifier from the
 cypertext before calling the L<decrypt_auth_ascii> method.
 
+=head2 encrypt_auth_urlsafe
+
+  my $ciphertext = $ea->encrypt_auth_urlsafe( $plaintext );
+
+Added in version 1.006.
+
+Encrypts the plain text (or any other Perl object that C<Storable> can
+freeze and thaw) passed as a parameter, generating an ASCII (modified
+base64) cipher text output.  This output is safe to pass as part of a
+query string or URL.  Namely, it doesn't use the standard Base 64
+characters C<+> or C</>, replacing them with C<-> and C<_> respectively.
+In addition, the cyphertext output will start with a "3" rather than the
+"2" that the base 64 variant starts with.
+
 =head2 decrypt_auth
 
   my $plaintext = $ea->decrypt_auth( $ciphertext );
@@ -317,6 +346,10 @@ greatly appreciate being notified via email sent to jmaslak@antelope.net
 prior to public disclosure. In the event of such notification, I will
 attempt to work with you to develop a plan for fixing the bug.
 
+All other bugs can be reported via email to jmaslak@antelope.net or by
+using the Git Hub issue tracker
+at L<https://github.com/jmaslak/Crypt-EAMessage/issues>
+
 =head1 AUTHOR
 
 Joelle Maslak <jmaslak@antelope.net>
